<template>
  <el-dialog
    v-bind="$attrs"
    title="添加成员"
    width="586px"
    custom-class="dialog-pick-up"
    :close-on-click-modal="false"
    :close-on-press-escape="false"
    v-dialog-drag
    :modal="false"
    @open="onOpen"
  >
    <div class="transfer">
      <!-- 候选 -->
      <div class="transfer-left">
        <el-input class="transfer-left-query" placeholder="搜索" v-model="pickupName" @input="queryPickup"></el-input>
        <div class="transfer-left-list">
          <div class="transfer-left-list-item" v-for="(item, index) in pickupMemberList" :key="index">
            <el-checkbox v-model="item.checked" @change="(val) => setCheck(item, val)">
              <div class="info">
                <el-avatar :size="30">
                  <div class="avatar">{{ item.nameSlice }}</div>
                </el-avatar>
                <span class="name">{{ item.name }}</span>
              </div>
            </el-checkbox>
          </div>
        </div>
      </div>
      <div class="transfer-right">
        <div class="transfer-right-header">
          <span class="count">已选：{{ unParticipated.filter((x) => x.checked === true).length }}人</span>
          <span class="clear" @click="clearPickup">清空</span>
        </div>
        <div class="transfer-right-list">
          <div
            class="transfer-right-list-item"
            v-for="(item, index) in unParticipated.filter((x) => x.checked === true)"
            :key="index"
          >
            <div class="info">
              <el-avatar :size="30">
                <div class="avatar">{{ item.nameSlice }}</div>
              </el-avatar>
              <span class="name">{{ item.name }}</span>
            </div>
            <i class="icon-remove" @click="unCheck(item)"></i>
          </div>
        </div>
      </div>
    </div>
    <div slot="footer" class="dialog-footer">
      <el-button @click="close">取 消</el-button>
      <el-button type="primary" @click="addMembers">确 定</el-button>
    </div>
  </el-dialog>
</template>

<script>
import { mapActions, mapMutations, mapState } from "vuex";

export default {
  name: "unParticipatedList",
  components: {},
  props: {},
  data() {
    return {
      pickupName: "",
      pickupMemberList: [],
    };
  },
  computed: {
    ...mapState({
      unParticipated: ({ gwsd }) => gwsd.unParticipated,
    }),
  },
  watch: {},
  methods: {
    ...mapActions(["getUnParticipated", "addMQTTGroupUsers"]),
    ...mapMutations([
      "UPDATE_UN_PARTICIPATED" /*更新在调度范围内但是未参会的人员信息*/,
      "UNCHECK_ALL_UN_PARTICIPANT" /*反选所有在调度范围内但是未参会的人员*/,
    ]),
    async onOpen() {
      // 获取在调度范围内但是未参会的人员
      this.pickupMemberList = await this.getUnParticipated();
    },
    close() {
      this.UNCHECK_ALL_UN_PARTICIPANT();
      this.$emit("close");
      this.$emit("update:visible", false);
    },
    queryPickup(val) {
      if (val) {
        this.pickupMemberList = this.unParticipated.filter((x) => {
          return x.name.indexOf(val) >= 0;
        });
      } else {
        this.pickupMemberList = this.unParticipated;
      }
    },
    clearPickup() {
      this.UNCHECK_ALL_UN_PARTICIPANT();
    },
    setCheck(member, checked) {
      const index = this.unParticipated.findIndex((x) => x.id === member.id);
      this.UPDATE_UN_PARTICIPATED({
        index,
        member: {
          ...member,
          checked,
        },
      });
    },
    unCheck(member) {
      const index = this.unParticipated.findIndex((x) => x.id === member.id);
      this.setCheck(index, member, false);
    },
    addMembers() {
      const members = this.unParticipated.filter((x) => x.checked === true);
      console.log("%c add member members", "background: #00cc00; color: #fff; border-radius: 3px;padding:2px 5px", members);
      if (!members || members.length === 0) {
        return false;
      }
      // 更新调度窗口的勾选状态
      const unParticipated = this.unParticipated.filter((item) => item.checked);
      const payload = unParticipated.map((item) => item.dispatchNo);
      this.addMQTTGroupUsers(payload).then(() => {
        // 去client组件发送信令
        this.$emit("addMembers", members);
        // 关闭弹窗
        this.close();
      });
    },
  },
  created() {},
  mounted() {},
};
</script>

<style scoped lang="css">
::v-deep .dialog-pick-up {
  background: transparent;
  border-radius: 8px;
  .el-dialog__header {
    height: 46px;
    background: #0f71ff;
    border-radius: 8px 8px 0 0;
    border: 1px solid #2f2f2f;
    padding: 0 16px;
    display: flex;
    align-items: center;
    .el-dialog__title {
      font-size: 14px;
      font-family: PingFang SC-Regular, PingFang SC, serif;
      font-weight: 400;
      color: #ffffff;
    }
    .el-dialog__headerbtn {
      top: 15px;
      right: 16px;
      .el-dialog__close {
        color: #ffffff;
      }
    }
  }
  .el-dialog__body {
    background: #1e1e1e;
    padding: 16px;
    .transfer {
      width: 100%;
      height: 499px;
      display: grid;
      grid-template-columns: repeat(2, 50%);
      grid-auto-rows: 100%;
      background: #1e1e1e;
      border: 1px solid #333333;
      border-radius: 8px;
      &-left,
      &-right {
        height: 100%;
      }
      &-left {
        padding: 12px;
        &-query {
          margin-bottom: 12px;
          .el-input__inner {
            width: 100%;
            height: 38px;
            background: #000000;
            border-radius: 8px 8px 8px 8px;
            border: 1px solid #2b2b2b;
            color: #ffffff;
            &::placeholder {
              font-size: 14px;
              font-family: PingFang SC-Regular, PingFang SC, serif;
              font-weight: 400;
              color: #999999;
            }
          }
        }
        &-list {
          width: 100%;
          height: calc(100% - 50px);
          overflow-x: hidden;
          overflow-y: auto;
          &-item {
            width: 100%;
            height: 46px;
            border-radius: 8px 8px 8px 8px;
            //cursor: pointer;
            margin-bottom: 8px;
            display: flex;
            align-items: center;
            &:hover,
            &-active {
              width: 100%;
              background: #2b2b2b;
            }
            .info {
              display: flex;
              align-items: center;
              .avatar {
                width: 100%;
                height: 100%;
                border-radius: 50%;
                overflow: hidden;
                //margin-right: 16px;
                background: #0e71ff;
                font-size: 12px;
                font-weight: 400;
                color: #ffffff;
                //margin-right: 8px;
                img {
                  width: 100%;
                  height: auto;
                }
              }
              .name {
                font-size: 12px;
                line-height: 20px;
                font-family: PingFang SC-Regular, PingFang SC, serif;
                font-weight: 400;
                color: #ffffff;
                margin-left: 12px;
              }
            }
          }
        }
      }
      &-right {
        border-left: 1px solid #333333;
        padding: 0 12px;
        &-header {
          width: 100%;
          height: 62px;
          display: flex;
          align-items: center;
          justify-content: space-between;
          .count {
            font-size: 14px;
            font-family: PingFang SC-Regular, PingFang SC, serif;
            font-weight: 400;
            color: #ffffff;
          }
          .clear {
            font-size: 14px;
            font-family: PingFang SC-Regular, PingFang SC, serif;
            font-weight: 400;
            color: #0f71ff;
            cursor: pointer;
          }
        }
        &-list {
          width: 100%;
          height: calc(100% - 62px);
          overflow-x: hidden;
          overflow-y: auto;
          &-item {
            width: 100%;
            height: 46px;
            border-radius: 8px 8px 8px 8px;
            //cursor: pointer;
            margin-bottom: 8px;
            display: flex;
            align-items: center;
            justify-content: space-between;
            padding: 0 16px;
            &:hover,
            &-active {
              width: 100%;
              background: #2b2b2b;
            }
            .info {
              display: flex;
              align-items: center;
              .avatar {
                width: 100%;
                height: 100%;
                border-radius: 50%;
                overflow: hidden;
                //margin-right: 16px;
                background: #0e71ff;
                font-size: 12px;
                font-weight: 400;
                color: #ffffff;
                //margin-right: 8px;
                img {
                  width: 100%;
                  height: auto;
                }
              }
              .name {
                font-size: 12px;
                line-height: 20px;
                font-family: PingFang SC-Regular, PingFang SC, serif;
                font-weight: 400;
                color: #ffffff;
                margin-left: 12px;
              }
            }
            .icon-remove {
              width: 12px;
              height: 12px;
              display: block;
              cursor: pointer;
              background: url("~@/assets/images/conversation/关闭 2.png") no-repeat;
              background-size: 100% 100%;
            }
          }
        }
      }
    }
  }
  .el-dialog__footer {
    background: #1e1e1e;
    height: 70px;
    padding: 0 16px;
    display: flex;
    align-items: center;
    justify-content: flex-end;
    .el-button {
      width: 120px;
      height: 38px;
      font-size: 14px;
      &--default {
        color: #ffffff;
        background: transparent;
        border: 1px solid #666666;
      }
    }
  }
}
</style>
